@@ -115,10 +115,10 @@ num.polygons <- function(p) {
   else 1 + sum(is.na(p[, 1]))
 }
 
-range.polygon <- function(..., na.rm = FALSE) {
-  p <- as.list.polygon(...)
-  lapply(p[c("x", "y")], range, na.rm = na.rm)
-}
+# range.polygon <- function(..., na.rm = FALSE) {
+#   p <- as.list.polygon(...)
+#   lapply(p[c("x", "y")], range, na.rm = na.rm)
+# }
 
 map.text <- function(database, regions = ".", labels, cex = 0.75, add = FALSE,
                      move = FALSE, ...) {
